Exception: Dandelionapi::WrongParameterFormat
- Inherits:
-
Exception
- Object
- Exception
- Dandelionapi::WrongParameterFormat
- Defined in:
- lib/dandelionapi.rb
Overview
Exception raised when a parameter is in the wrong format
Exception raised when a parameter is in the wrong format